# Sample Code

Export your license key as `TRUEFACE_TOKEN` environment variable.

To run the sample code, run `python3 file_name`.

Some models may need to be downloaded to be loaded at runtime (running the inference function will throw an error if the model is not found).
For these models, run the scripts located in the `download_models` directory to obtain the models. Be sure to specify the `models_path` configuration option.

If the python interpreter is unable to find `tfsdk`, ensure the version of the library 
you are using matches your python version (including minor version) exactly. 

If using the GPU library, ensure that `libtf.so` is in your `LD_LIBRARY_PATH`. 
You can confirm this by running `ldd` on the bindings library and ensuring that all dependencies are met. 

### Chip Extraction
`chip_extraction.py` demonstrates how to extract and display an aligned 112x112 chip from a face image.

### Spoof Detection
`detect_spoof.py` demonstrates how to run spoof detection on an image. Spoof is detected when a user is trying to impersonate an identity, for example by holding a phone with a face image up to the camera. Note you will need to run the download script in /download_models to obtain the spoof model file.

### Face recognition
`face_recognition.py` demonstrates how to load images from disk then generate feature vectors for each of the images then run 1 to 1 matching. Note you will need to run the download script in /download_models to obtain the TFV5 model file.

`face_recognition_image_buffer.py` demonstrates how to load images directly from a buffer. This demo requires the `opencv-python` module to be installed. Note you will need to run the download script in /download_models to obtain the TFV5 model file.

### 1 to N matching
`identification.py` demonstrates how to create and populate a collection with face templates. Later, the collection can be searched using a new face image to see if there is an identity match. Note you will need to run the download script in /download_models to obtain the TFV5 model file. 

`identification.py` demonstrates how to perform 1 to N matching using a video stream. Note you will need to run the download script in /download_models to obtain the TFV5 model file.

### Object Detection
`object_detection.py` demonstrates how to use the object detection module on static images.

`object_detection_live_streaming.py` demonstrates a live streaming application. Frames are obtained from the users camera then object detection is run on these frames. The results are drawn to the scree. This demo requires the `opencv-python` module to be installed.

### Blur
`blur_live_streaming.py` demonstrates a live streaming application. Frames are obtained from the users camera then face detection is run on these frames. The detected faces are then blurred. The results are drawn to the scree. This demo requires the `opencv-python` module to be installed.

### Pose Estimation
`head_pose_estimation.py` demonstrates how to compute the yaw pitch and roll of a face image.

`body_pose_estimation.py` demonstrates how to draw the human body pose on an input image. Note you will need to run the download script in /download_models to obtain the body pose model file.

`body_face_pose_live_streaming.py` demonstreates how to draw the body pose on a live stream, and also draw the head orientation axis arrows on the live stream. Note you will need to run the download script in /download_models to obtain the body pose model file.

### Liveness
`blink_detection.py` demonstrates how to run blink detection on an image, and can be used for liveness.

### Mask Detection
`detect_mask.py` demonstrates how to run mask detection on an image. Mask is detected when a user is wearing a face mask.

### Eye glasses Detection
`detect_eyeglasses.py` demonstrates how to run eye glasses detection on an image. Glasses are detected when a user is wearing some type of glasses.

### VRAM
`test_fr_vram.py` demonstrates how you can uses images from GPU RAM.
You will need to have cupy installed to run this sample app.